% Example of a network of sensors mounted on robots
%
% Inputs:
%    o: [optional] true if we have to fix the relative orientation of
%       particuarl triangles. If not given true is assumed.

function exampleRobots(varargin)

  % Define the problem
  %   P: Problem
  %  D1: Distance matrix as obtanied from sensors
  %  D2: Distance matrix after triangular inequality
  [P,D1,D2]=robots(varargin{1:end}); % true to include orientation constraints
  R1=D1.U-D1.L;
  R2=D2.U-D2.L;
  
  % Solve the problem
  S=solveProblem(P);
  
  % for all the solutions
  ns=length(S);
  for i=1:ns
    
    % Plot the solution
    figure;
    plotSolution(S{i},'R');
  
  end
  
  if isempty(varargin) || varargin{1}   
    % Here we only have one solution  
    
    % Plot the evolution of the range reduction
    R3=S{1}.U-S{1}.L;
    
    figure;
    vs=triu(P.V);
    lbs={'d_{1,4}' 'd_{1,5}' 'd_{1,6}' 'd_{3,5}' 'd_{3,6}' 'd_{4,5}'};
    bar(min(20,sqrt(R1(vs))),'y');
    hold on;
    bar((sqrt(R2(vs))),'b');
    bar((sqrt(R3(vs))),'r');
    set(gca,'XTickLabel',lbs,'FontSize',18);
    ylabel('Ranges');
    legend('Raw sensors','Triangular inequality','Proposed method','Location','southeastoutside');
    
    
    % Print the matrices in latex format
    printMatrix(D1,1);
    printMatrix(D2,2);
    printMatrix(D3,3);
  end
end


function printMatrix(D,id)
  fprintf('\\begin{equation*}\n');
  fprintf('  {\\bf D_{%d}} {=}\n',id);
  fprintf('  \\begin{pmatrix}\n');
  for i=1:D.n
    fprintf('        ');
    for j=1:D.n
      fprintf('[%5.2f,%5.2f] ',D.L(i,j),D.U(i,j));
      if j<D.n
        fprintf('& ');
      else
        fprintf('\\\\ \n');
      end
    end
  end
  fprintf('  \\end{pmatrix}\n');
  fprintf('\\end{equation*}\n\n\n');
end
