% Example of a network of sensors mounted on robots solved using MDS.
%
% Inputs:
%    rep: [optional] number of repetitions. If not given 100 is used.
%         MDS samples in the given input ranges and, therefore, we have to
%         solve many times the same problem to get statistics.

function exampleRobotsMDS(varargin)

  % Fix the number of repetitions
  if ~isempty(varargin)
    rep=varargin{1};
  else
    rep=100;
  end

  % Define the problem
  %   P: Problem. Not used here
  %  D1: Distance matrix as obtanied from sensors
  %  D2: Distance matrix after triangular inequality (not used here)
  [P,D1,~]=robots; % without parameters=
  
  nInside=0;
  for i=1:rep
    
    % Solve the problem
    [S,inside]=solveProblemMDS(P,D1);
    
    if i==1
      % Display the solution
      plotSolution(S,'R');
    end
    
    if inside
      nInside=nInside+1;
    end
  end
  
  fprintf('Percentage of outputs inside the input ranges: %f\n',nInside/rep);
  
  
