% Three dimensional representation of a box. The box is defined from ranges
% in the problem.
% 
% Inputs:
%     P: A solution. Can also be a set of solutions and then all of them
%        ara plotted. Each solution is represented by matrices of lower 
%        and upper bounds.
% alpha: The transparency [0,1].
%    r1: Row of the first variable to used to define the box.
%    c1: Column of the first variable to used to define the box.
%    r2: Row of the second variable to used to define the box. Optional. If
%        not given 0 is used.
%    c2: Column of the second variable to used to define the box. Optional. 
%        If not given 0 is used.
%    r3: Row of the third variable to used to define the box. Optional. If
%        not given 0 is used.
%    c3: Column of the third variable to used to define the box. Optional. 
%        If not given 0 is used.
%
function plotBox(P,alpha,r1,c1,r2,c2,r3,c3)

  hold on;
  if iscell(P)
    
    if nargin>6
      pt=@(x)(plotBox(x,alpha,r1,c1,r2,c2,r3,c3));
    else
      if nargin>4
        pt=@(x)(plotBox(x,alpha,r1,c1,r2,c2));
      else
        pt=@(x)(plotBox(x,alpha,r1,c1));
      end
    end
    cellfun(pt,P,'UniformOutput',false);
    
  else
    
    ms=0.0001; %5; %0.001;
    if ms==0
      eps=0.01;
    else
      eps=ms/2;
    end
    
    l1=P.L(r1,c1);
    s1=P.U(r1,c1)-l1;
     if s1<ms
       s1=ms;
     end
    
    if nargin>4
      l2=P.L(r2,c2);
      s2=P.U(r2,c2)-l2;
       if s2<ms
         s2=ms;
       end
    else
      l2=-eps;
      s2=2*eps;
    end
    
    if nargin>6
      l3=P.L(r3,c3);
      s3=P.U(r3,c3)-l3;
       if s3<ms
         s3=ms;
       end
    else
      l3=-eps;
      s3=2*eps;
    end
    
    % enlarge isolated boxes
    if s1<ms && s2<ms && s3<ms
      s1=ms;
      s2=ms;
      s3=ms;
    end
    
    voxel([l1 l2 l3],[s1 s2 s3],'r',alpha);
    
  end
  hold off;