% Plots a solution. Computes the coordinates of the points from the
% interpoint distances and plots them. 
% Point with fixed distance are connected by a solid line and points whose
% distance can vary are connected by dashed lines.
%
% Inputs:
%    P: The solution to plot.
%   lb: [optional] label to use in the points 
%
% Outputs:
%
%
function plotSolution(P,varargin)

  hold on;
  if iscell(P)
    ps=@(x)plotSolution(x,varargin{1:end});
    cellfun(ps,P,'UniformOutput',false);
  else
    if isempty(varargin)
      label=false;
    else
      label=true;
      txt=varargin{1};
    end
    
    S=(P.U+P.L)/2;
    
    % A=X1*X1'
    % where X1 includes the vectors x_i-x_n
    % but computed from distances using the cosinus theorem
    E=[zeros(P.n-1,P.n);ones(1,P.n)]-0.5*eye(P.n);
    B=S*E;
    A=0.5*(B+B');
    
    % C=chol(A(1:(n-1),1:(n-1)));
    % X=[C zeros(n-1,1);zeros(1,n)];
    % X=X(1:3,:)';
    [L,D,Pe]=ldl(A);
    % L*D*L'=Pe'*A*Pe = Pe'*X1*X1'*Pe
    % L*sqrt(D)=Pe'*X1
    % X1=Pe*L*sqrt(D)
    X=Pe*L*sqrt(D(:,1:P.dim));
    
    t=X(1,:);
    vx=(X(2,:)-X(1,:));
    vx=vx/norm(vx);
    vy=(X(3,:)-X(1,:));
    vy=vy-vy*(vx'*vx);
    vy=vy/norm(vy);
    if P.dim==2
      T=[vx' vy' t'; 0 0 1];
    else
      vz=cross(vx,vy);
      T=[vx' vy' vz' t'; 0 0 0 1];
    end
    T=T\eye(P.dim+1);
    X2=T*[X'; ones(1,P.n)];
    X=X2(1:P.dim,:)';
    
    if P.dim==3 && X(4,P.dim)<0
      for i=4:P.n
        X(i,P.dim)=-X(i,P.dim);
      end
    end
    
    for i=1:P.n
      % Label for each point
      if label
        if P.dim==2
          text(X(i,1)+0.1,X(i,2)+0.4,['  ' sprintf('%s_{%u}',txt,i)],'HorizontalAlignment','left','FontSize',18);
        else
          text(X(i,1)+0.1,X(i,2)+0.4,X(i,3),['  ' sprintf('%s_{%u}',txt,i)],'HorizontalAlignment','left','FontSize',19);
        end
      end
      
      for j=(i+1):P.n
        if P.dim==2
          h=line([X(i,1) X(j,1)],[X(i,2) X(j,2)]);
        else
          h=line([X(i,1) X(j,1)],[X(i,2) X(j,2)],[X(i,3) X(j,3)]);
        end
        if P.V(i,j)
          set(h,'color','r','linestyle','--');
        else
          set(h,'linewidth',2);
        end
      end
    end
    axis equal;
  end
  hold off;
