% The monotonicity analysis
% We use the symbolic toolbox to verify that the monotonicity analysis is
% correct (i.e. that the derivatives are correct).

%--------------------------------------------------------------------------
syms d_1_n d_1_j d_j_n d_1_i d_i_n d_i_j

%--------------------------------------------------------------------------
% Projection on v_1_n

% General cas of the projection on v_1_n
p_i_j=(d_1_j^2-d_j_n^2-d_1_i^2+d_i_n^2)/(2*d_1_n);

% particular cases with j=n and i=1
p_i_n=(d_1_n^2+d_i_n^2-d_1_i^2)/(2*d_1_n);
p_1_j=(d_1_n^2+d_1_j^2-d_j_n^2)/(2*d_1_n);

% Monotonicity analysis

% General case
diff(p_i_j,d_1_j)-(d_1_j/d_1_n)
diff(p_i_j,d_j_n)-(-d_j_n/d_1_n)
diff(p_i_j,d_i_n)-(d_i_n/d_1_n)
diff(p_i_j,d_1_i)-(-d_1_i/d_1_n)
diff(p_i_j,d_1_n)-(-p_i_j/d_1_n)

% Particular case p_i_n
diff(p_i_n,d_i_n)-(d_i_n/d_1_n)
diff(p_i_n,d_1_i)-(-d_1_i/d_1_n)
diff(p_i_n,d_1_n)-(1-p_i_n/d_1_n)

% Particular case p_1_j
diff(p_1_j,d_j_n)-(-d_j_n/d_1_n)
diff(p_1_j,d_1_j)-(d_1_j/d_1_n)
diff(p_1_j,d_1_n)-(1-p_1_j/d_1_n)

%--------------------------------------------------------------------------
% Projection on the subspace orthonormal to v_1_n
% We actually compute the squared of the projections

% General case 
o_i_j=d_i_j^2-p_i_j^2;

% particular cases with j=n and i=1
o_i_n=d_i_n^2-p_i_n^2;
o_1_j=d_1_j^2-p_1_j^2;

% Monotonicity analysis

% General case
diff(o_i_j,d_i_j)-(2*d_i_j)
diff(o_i_j,d_1_j)-(-d_1_j*2*p_i_j/d_1_n)
diff(o_i_j,d_j_n)-(d_j_n*2*p_i_j/d_1_n)
diff(o_i_j,d_i_n)-(-d_i_n*2*p_i_j/d_1_n)
diff(o_i_j,d_1_i)-(d_1_i*2*p_i_j/d_1_n)
diff(o_i_j,d_1_n)-(2*p_i_j^2/d_1_n)

% Particular case o_1_j
simplify(diff(o_1_j,d_1_j)-(2*d_1_j*(1-p_1_j/d_1_n)))
diff(o_1_j,d_j_n)-(d_j_n*p_1_j*2/d_1_n)
simplify(diff(o_1_j,d_1_n)-(-2*p_1_j*(1-p_1_j/d_1_n)))

% Particular case o_i_n
diff(o_i_n,d_1_i)-(d_1_i*p_i_n*2/d_1_n)
simplify(diff(o_i_n,d_i_n)-(2*d_i_n*(1-p_i_n/d_1_n)))
simplify(diff(o_i_n,d_1_n)-(-2*p_i_n*(1-p_i_n/d_1_n)))

