% Auxiliary function to plot the situation encountered when reducing the
% projections of a point on a given axis and on its orthogonal projection.
%
% Inputs:
%     i: The index of the point. Please, be aware that this is applied
%        after permuting the points so that the projection axis is defined
%        by the first and the last point.
%     P: The description of the problem. It includes the lower and upper
%        bounds for the squared distances between the points.
%     O: The squared distances in the orthogonal projection.
%     V: The projection on the projection axis. These are not squared and
%        can be interpreted as coordinates on the projection axis.
%    Ot: O after the reduction.
%    Vt: V after the reduction
%
% Outputs:
%     h: The handler of the figure. The figure includes the range of
%        distance 1-i (in blue) and i-n (in red) (including the possible 
%        range 1-n) before and after the reduction. The figure also shows
%        the initial range for the projections on the projectin axis and on
%        the orthogonal sub-space before an after the projection (in black
%        and green, respectively). The projections intersect in a box that
%        should tightly bound the valid area for the position of point 'i',
%        i.e., the area in between the blue and red circles.
%
%
function h=plotSituation(i,P,O,V,Ot,Vt)

  h=figure(1);
  
  axis equal;
  hold on;
  
  ang=0:0.01:2*pi;
  
  r=sqrt(P.L(1,i));x=0;y=0;xp=r*cos(ang);yp=r*sin(ang);plot(x+xp,y+yp);
  r=sqrt(P.U(1,i));x=0;y=0;xp=r*cos(ang);yp=r*sin(ang);plot(x+xp,y+yp);
  
  r=sqrt(P.L(P.n,i));x=sqrt(P.L(1,P.n));y=0;xp=r*cos(ang);yp=r*sin(ang);plot(x+xp,y+yp,'r');
  r=sqrt(P.U(P.n,i));x=sqrt(P.U(1,P.n));y=0;xp=r*cos(ang);yp=r*sin(ang);plot(x+xp,y+yp,'r');
  
  plot([V.L(1,i) V.L(1,i)],[-2 2],'k');
  plot([V.U(1,i) V.U(1,i)],[-2 2],'k');
  
  plot([-2,2],[sqrt(O.L(1,i)) sqrt(O.L(1,i))],'k');
  plot([-2,2],[sqrt(O.U(1,i)) sqrt(O.U(1,i))],'k');
  
  plot([Vt.U(1,i) Vt.U(1,i)],[-2 2],'g');
  plot([Vt.L(1,i) Vt.L(1,i)],[-2 2],'g');
  
  plot([-2,2],[sqrt(Ot.U(1,i)) sqrt(Ot.U(1,i))],'g');
  plot([-2,2],[sqrt(Ot.L(1,i)) sqrt(Ot.L(1,i))],'g');
  
  hold off;