% Permutes a problem so that two particular points are at positions 1 and
% n.
%
% Inputs:
%     P: The problem.
%     r: Reverse permutation.
% level: Recursion level
%    np: Current projection.
%     i: The point to be at position 1.
%     j: The point to be at position n.
% Outputs:
%    P1: The permuted problem.
%   ndx: The permutation used. 
%
function [P1,ndx]=permute1n(P,r,level,np,i,j)

  if i==j
    error('repeated index in permutation');
  end
  
  if i<1 || i>P.n || j<1 || j>P.n
    error('index out of range in permutation');
  end
  P1=P;
  
  if i==P.n && j==1
    ndx=1:P.n;
    ndx(1)=P.n;
    ndx(P.n)=1;
  else
    % Permute 1 and i
    p1=1:P.n;
    p1(i)=1;
    p1(1)=i;
    
    % Permute j and P.n
    p2=1:P.n;
    p2(j)=P.n;
    p2(P.n)=j;
    
    % Compose permutations
    if r
      ndx=p1(p2);
    else
      ndx=p2(p1);
    end
  end
  
  P1.L=P.L(ndx,ndx);
  P1.U=P.U(ndx,ndx);
  P1.V=P.V(ndx,ndx);
  
  if np>0
    P1.sg{np}=P1.sg{np}(ndx,ndx);
    
    % apply first and second permutations
    m=size(P1.proj{np},2);
    for k=2*level+1:m
      P1.proj{np}(k)=find(ndx==P1.proj{np}(k));
    end
  end
  