% Reduces a box defined by the ranges bounding the solutions of the 
% problem at hand. 
% Those ranges are stored in the structure P with the lower and upper
% bounds for the squared distances between points. P also includes other
% parameters, though. The ranges are reduced by projecting the inter-point
% distances to a given axis and its orthgonal subspace, reducing the ranges
% in this subsapce, propagating the eventual reductions to the projections
% on the projection axis and, finally, backprojecting to determine tighter
% bound in the original space.
% The projection axis are defined by two point in the problem and the
% different couples to consider are stored in P.
%
% Inputs:
%     P: The problem with the ranges to reduce.
%
% Outputs:
%     P: The problem with the possibly reduced ranges.
% empty: True if the problem is determined to be unfeasible, i.e, the given
%        box is empty.
%     s: A matrix indicating which ranges should be used to split the
%        problem, i.e,. ranges than when split are likely to separate two
%        solutions.
%    np: Number of projections actually computed. Used to gather statistics
%        about the solution process.
%
% 
function [P,empty,s,np,red,nRed]=reduceBox2(P,red,nRed)
  [P,empty,s,np]=reduceBox2Int(P,1);
end

function [P,empty,s,np]=reduceBox2Int(P,level)

  empty=false;
  s=zeros(P.n);
  
  np=0;
  i=1;
  while ~empty && i<P.n
    j=i+1;
    while ~empty && j<=P.n
            
      P1=permute1n(P,false,level,0,i,j);
      
      % project
      [V,O,empty,er]=project(P1);
      np=np+1;
      
      % reduce
      if ~empty && ~er
        if O.dim==1
          [Ot,empty,s1]=triangEq2(O,P1.sg{np});
        else
          [Ot,empty,s1,np1]=reduceBox2Int(O,level+1);
          np=np+np1;
        end
        
        if ~empty
          % Add the missing point to Ot
          [Ot,s1]=addMissingPoint(Ot,s1);
          
          % translate the reduction to V
          [Vt,empty]=O2V(P1,Ot,V); % includes triangEq(Vt)
          %Vt=triangEq(V);
          %Vt=V;
          if ~empty
            % Backprocject.
            [P1,empty]=backprojection(P1,Vt,Ot);
          end
        end
      
        if ~empty
          [P,ndx]=permute1n(P1,true,level,0,i,j);
          s=s+s1(ndx,ndx);
        end
      
      end
      
      j=j+1;
    end
    i=i+1;
  end
  
end
