% Applies the triangular equality.
% This only works on one-dimensional spaces and assumes oriented distances
% (i.e, oriented vectors on the one-dimensional space).
%
% Inputs:
%     V: The matrix of oriented distances between the points on the line.
%   eps: Numerical accuracy.
% 
% Outputs: 
%    V1: The matrix with the possibly reduced oriented distances.
% empty: True if during the process the problem is determined to be
%        unfeasible on the given ranges.
%
function [V1,empty]=triangEq(V,eps)

  roundUp=@()(system_dependent('setround',Inf));
  roundDown=@()(system_dependent('setround',-Inf));
  roundNear=@()(system_dependent('setround','nearest'));
  
  if V.dim>1
    error('triang works one dimensinal spaces');
  end
  
  V1=V;
   
  empty=false;
  j=1;
  while ~empty && j<=V.n
    i=1;
    while ~empty && i<V.n
      k=i+1;
      while ~empty && k<=V.n
        if V1.U(i,k)-V.L(i,k)>1e-10
          roundDown();
          mi=V1.L(i,j)+V1.L(j,k)-eps;
          roundUp();
          ma=V1.U(i,j)+V1.U(j,k)+eps;
          roundNear();
          
          l1=max(V1.L(i,k),mi);
          u1=min(V1.U(i,k),ma);
          
          roundNear();
          
          if l1>u1
            empty=true;
          else
            V1.L(i,k)=l1;
            V1.U(i,k)=u1;
            
            V1.L(k,i)=-V1.U(i,k);
            V1.U(k,i)=-V1.L(i,k);
          end
        end
        k=k+1;
      end
      i=i+1;
    end
    j=j+1;
  end
  