% Applies the triangular inequality on a matrix of squared distance between
% points.
%
% Inputs: 
%     P: The input problem with the squared lower and upper bounds for each
%        interpoint distance.
%
% Outputs:
%    P1: The problem with reduced ranges.
% empty: True if the problem is determined to be unfeasible.
%
function [P1,empty]=triangIneq(P)

  roundUp=@()(system_dependent('setround',Inf));
  roundDown=@()(system_dependent('setround',-Inf));
  roundNear=@()(system_dependent('setround','nearest'));
  
  P1=P;
  empty=false;
  for i=1:(P1.n-1)
    for k=i+1:P1.n
      if P1.V(i,k)
        for j=1:P1.n
          roundDown();
          l=max(sqrt(P1.L(i,j))-sqrt(P1.U(j,k)),sqrt(P1.L(j,k))-sqrt(P1.U(i,j)));
          roundUp();
          u=sqrt(P1.U(i,j))+sqrt(P1.U(j,k));
          
          roundDown();
          a=max(sqrt(P1.L(i,k)),l);
          roundUp();
          b=min(sqrt(P1.U(i,k)),u);
          roundNear();
          
          if a>b
            empty=true;
          end
          
          P1.L(i,k)=a*a;
          P1.U(i,k)=b*b;
          
          P1.L(k,i)=P1.L(i,k);
          P1.U(k,i)=P1.U(i,k);
        end
      end
    end
  end
  