% Generates a random instance of the 3RPR problem.
%
% Inputs:
%     s1: Size of the base.
%     s2: Size of the platform.
%
% Outputs:
%      P: The problem structure.
%
% Example of use:
%     P=P3RPR(1,0.25)
%
function P=P3RPRRandom(s1,s2)

  x1=[0  0];
  x2=[s1 0];
  x3=[s1/2 s1*sqrt(0.75)];
  
  a=0+(pi/4)*(2*rand()-1);
  x=0+0.5*s1*rand();
  y=0+0.5*s1*rand();
  T=[cos(a) sin(a);-sin(a) cos(a)];
  
  x4=[x y];
  x5=[s2 0]*T+[x y];
  x6=[s2/2 s2*sqrt(0.75)]*T+[x y];
  
  X=[x1;x2;x3;x4;x5;x6];
  
  [P.n,P.dim]=size(X);
  
  P.L=squareform(pdist(X)).^2;
  P.U=P.L;
  P.V=logical([0 0 0 0 1 1
               0 0 0 1 0 1
               0 0 0 1 1 0
               0 1 1 0 0 0
               1 0 1 0 0 0
               1 1 0 0 0 0]);
  P.L(P.V)=0;
  P.U(P.V)=100;
  
  fprintf('P3RPR.dat\n');
  for i=1:P.n
    for j=1:P.n
      if j<=i
        fprintf('%9.5f %9.5f   ',0,0);
      else
        fprintf('%9.5f %9.5f   ',P.L(i,j),P.U(i,j));
      end
    end
    fprintf('\n');
  end
  
  P.eps=1e-15*max(max(P.U));
  P.sigma=0.01;
  P.rho=0.9;
  P.maxSize=true;
  
  P.dim=2;
 
  [P,empty]=triangIneq(P);
  
  if empty
    error('inconsistent problem');
  end
  
  Z=zeros(P.n);
  Z1=Z;
  % Set this to +/-1 to select one of the solutions
  %Z1(2,4)=-1;
  %Z1(4,2)=-1;
  %Z1(2,5)=-1;
  %Z1(5,2)=-1;
  Z1(2,6)=-1;
  Z1(6,2)=-1;
  
  P.proj={ [1 2] [1  3] [1 4] [1 5] [1 6] [2 3] [2 4] [2 5] [2 6] [3 4] [3 5] [3 6] [4 5] [4 6] [5 6] };
  P.sg=  {   Z     Z1     Z     Z     Z     Z     Z     Z     Z     Z     Z     Z     Z     Z     Z   };
  
  P.nProj=size(P.proj,2);
  