% Generates a random instance of the octahedral problem.
%
% Inputs:
%     s1: Size of the base.
%     s2: Size of the platform.
%
% Outputs:
%      P: The problem structure.
%
% Example of use:
%     P=octahedralRandom(1,0.25)
%
function P=octahedralRandom(s1,s2)

  x1=[-s1/2 -s1*sqrt(0.75)/2 0];
  x2=[+s1/2 -s1*sqrt(0.75)/2 0];
  x3=[  0   +s1*sqrt(0.75)/2 0];
  
  x4=[  0   -s2*sqrt(0.75)/2 0];
  x5=[-s2/2 +s2*sqrt(0.75)/2 0];
  x6=[+s2/2 +s2*sqrt(0.75)/2 0];
  
  na=0.4;
  ax=2*na*rand()-na;
  Rx=[1   0        0     0
      0 cos(ax) -sin(ax) 0
      0 sin(ax)  cos(ax) 0
      0   0        0     1];
  ay=2*na*rand()-na;
  Ry=[ cos(ay) 0 sin(ay) 0
         0     1   0     0
      -sin(ay) 0 cos(ay) 0
         0     0   0     1];
  az=2*na*rand()-na;
  Rz=[cos(az) -sin(az) 0 0
      sin(az)  cos(az) 0 0
        0        0     1 0
        0        0     0 1];
  tx=2*0.1*s1*rand()-0.1*s1;
  ty=2*0.05*s1*rand()-0.05*s1;
  tz=0.5+2*0.1*s1*rand()-0.1*s1;
  T=[1 0 0 tx
     0 1 0 ty
     0 0 1 tz
     0 0 0 1];
  
  Tr=Rx*Ry*Rz*T;
  
  p=Tr*[x4 1 ; x5 1 ; x6 1]';
  
  x4=p(1:3,1)';
  x5=p(1:3,2)';
  x6=p(1:3,3)';
  
  X=[x1;x2;x3;x4;x5;x6];
  
  [P.n,P.dim]=size(X);
  
  P.L=squareform(pdist(X)).^2;
  P.U=P.L;
  P.V=logical([0 0 0 0 0 1
               0 0 0 0 1 0
               0 0 0 1 0 0
               0 0 1 0 0 0
               0 1 0 0 0 0
               1 0 0 0 0 0]);
  
  %P.L(P.V)=0;
  %P.U(P.V)=100;
  fprintf('P3RPR.dat\n');
  for i=1:P.n
    for j=1:P.n
      if j<=i
        fprintf('%9.5f %9.5f   ',0,0);
      else
        fprintf('%9.5f %9.5f   ',P.L(i,j),P.U(i,j));
      end
    end
    fprintf('\n');
  end

  P.eps=1e-15*max(max(P.U));
  P.sigma=0.01;
  P.rho=0.9;
  P.maxSize=true;
  
  P.dim=3;
 
  [P,empty]=triangIneq(P);
  
  if empty
    error('inconsistent problem');
  end
  
  Z=zeros(P.n);
  %Z1=Z;
  % Set this to +/-1 to select one of the solutions
  %Z1(2,4)=-1;
  %Z1(4,2)=-1;
  %Z1(2,5)=-1;
  %Z1(5,2)=-1;
  %Z1(2,6)=-1;
  %Z1(6,2)=-1;
  
  P.proj={ [1 2 1 3] [3 1 3 2] };
  P.sg=  {     Z         Z     };
  
  P.nProj=size(P.proj,2);
  
  