% Example with the octahedral parallel manipulator. 
% For the Sensor journal paper.
%
% Input:
%    orientation: [optional] true if we have to fix the relative 
%                 orientation of particuarl triangles. If not given true 
%                 is assumed.
% Outputs:
%     P: The problem structure.
%
function P=octahedralTRO(varargin)

  if isempty(varargin)
    orientation=true;
  else
    orientation=varargin{1};
  end
  
  % this problem has larger values -> usa a larger eps.
  P.eps=1e-12;
  
  P.L=[ 0   12  12   19.8  0 17.8
       12    0  12   18   18  0  
       12   12   0    0   17 14.9
       19.8 18   0    0    6  6 
        0   18  17    6    0  6
       17.8  0  14.9  6    6  0 ];
  P.L=P.L.^2-P.eps;
  P.L(P.L<0)=0;
  
  P.U=[ 0   12  12   19.8 90 17.8
       12    0  12   18   18 90  
       12   12   0   90   17 14.9
       19.8 18  90    0    6  6 
       90   18  17    6    0  6
       17.8 90  14.9  6    6  0 ];
  P.U=P.U.^2+P.eps;
  
  P.V=[ 0 0 0 0 1 0
        0 0 0 0 0 1
        0 0 0 1 0 0
        0 0 1 0 0 0
        1 0 0 0 0 0
        0 1 0 0 0 0];
  P.n=size(P.U,2);
  
  P.dim=3;
  
  P.sigma=5;
  P.rho=0.99;
  P.maxSize=true;
  
  Z=zeros(P.n);
  
  P.proj={};
  P.sg={};
  for i=1:P.n
    for j=i+1:P.n
        for k=1:P.n
          if k~=j
            for l=k+1:P.n
              if l~=j 
                P.proj=[P.proj [i j k l]];
                P.sg=[P.sg Z];
              end
            end
          end
        end
    end
  end
  
  if orientation
    %Z1=Z;
    %Z1(3,4)=-1;
    %Z1(4,3)=-1;
    % P.sg{77}=Z1; % 2 5 2 6
    
    Z1=Z;
    Z1(2,5)=-1;
    Z1(5,2)=-1;
    Z1(3,5)=-1;
    Z1(5,3)=-1;
    Z1(6,5)=-1;
    Z1(5,6)=-1;
    P.sg{24}=Z1; % 1 4 1 6
    
    Z1=Z;
    Z1(1,6)=-1;
    Z1(6,1)=-1;
    Z1(3,6)=-1;
    Z1(6,3)=-1;
    Z1(3,1)=-1;
    Z1(1,3)=-1;
    P.sg{66}=Z1; % 2 4 2 5
    
    Z1=Z;
    Z1(1,4)=-1;
    Z1(4,1)=-1;
    Z1(2,4)=-1;
    Z1(4,2)=-1;
    Z1(2,1)=-1;
    Z1(1,2)=-1;
    P.sg{109}=Z1; % 3 5 3 6
    
    
    Z1=Z;
    Z1(1,5)=+1;
    Z1(5,1)=+1;
    P.sg{67}=Z1; % 2 4 2 6
    
    Z1=Z;
    Z1(1,5)=+1;
    Z1(5,1)=+1;
    P.sg{99}=Z1; % 3 4 3 6
    
    
    Z1=Z;
    Z1(2,6)=+1;
    Z1(6,2)=+1;
    P.sg{23}=Z1; % 1 4 1 5
    
    Z1=Z;
    Z1(2,6)=+1;
    Z1(6,2)=+1;
    P.sg{98}=Z1; % 3 4 3 5
    
    Z1=Z;
    Z1(3,4)=+1;
    Z1(4,3)=+1;
    P.sg{34}=Z1; % 1 5 1 6
    
    Z1=Z;
    Z1(3,4)=+1;
    Z1(4,3)=+1;
    P.sg{77}=Z1; % 2 5 2 6
    
    Z1=Z;
    Z1(3,5)=-1;
    Z1(5,3)=-1;
    Z1(3,6)=-1;
    Z1(6,3)=-1;
    Z1(5,6)=-1;
    Z1(6,5)=-1;
    P.proj=[P.proj [4 1 4 2]];
    P.sg=[P.sg Z1];
    
    Z1=Z;
    Z1(1,4)=-1;
    Z1(4,1)=-1;
    Z1(1,6)=-1;
    Z1(6,1)=-1;
    Z1(4,6)=-1;
    Z1(6,4)=-1;
    P.proj=[P.proj [5 2 5 3]];
    P.sg=[P.sg Z1];
    
    Z1=Z;
    Z1(2,4)=-1;
    Z1(4,2)=-1;
    Z1(2,5)=-1;
    Z1(5,2)=-1;
    Z1(4,5)=-1;
    Z1(5,4)=-1;
    P.proj=[P.proj [6 1 6 3]];
    P.sg=[P.sg Z1];
  end
  
  P.nProj=size(P.proj,2);
  
  P=triangIneq(P);
  