% Reads the problem data stored in a file.
% Note that the output structure is only partially defined. Additional
% fields must be defined before using the structure (such as the
% parameters). See fourICRA for instance.
%
% Inputs:
%     file: The name of the file to read.
%
% Outputs:
%        P: The partially defined problem structure.
%
function P=readProblem(file)

  % Read problem with the squared distances
  array=load(file);
  [r,c]=size(array);
  
  c=c/2;
  P.L=zeros(r,c);
  P.U=zeros(r,c);
  ndx=1:c;
  P.L=array(:,2*ndx-1);
  P.U=array(:,2*ndx);
  P.L=P.L+P.L';
  P.U=P.U+P.U';
  P.V=P.L<P.U;
  P.n=r;
  
  P.eps=1e-15*max(max(P.U));
  
  P.L=P.L-P.eps;
  neg=(P.L<0);
  P.L(neg)=0;
  P.U=P.U+P.eps;
  
  [P,empty]=triangIneq(P);
  
  if empty
    error('inconsistent problem');
  end
  
